@@ -15,11 +15,11 @@ WWW::Twitpic::Fetch - Moose-based information scraper/fetcher for Twitpic
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -117,6 +117,7 @@ has _photo_scaled_scraper => (
       process 'div#view-photo-views>div' => 'views' => 'TEXT';
       process 'div#view-photo-caption' => 'message' => 'TEXT';
       process 'div.photo-comment' => 'comments[]' => $each_comment;
+			process 'div#view-photo-tags>a.nav' => 'tags[]' => 'TEXT';
     };
   },
 );
@@ -138,6 +139,20 @@ has _public_timeline_scraper => (
   },
 );
 
+has _tagged_scraper => (
+	is => q/ro/,
+	lazy => 1,
+	default => sub {
+		my $each = scraper {
+			process '.' => 'id' => '@href';
+			process 'img' => 'mini' => '@src';
+		};
+		scraper {
+			process 'div#main>center>div>a' => 'tagged[]' => $each;
+		};
+	},
+);
+
 =head1 FUNCTIONS
 
 =head2 list I<username> [, I<page>] 
@@ -207,7 +222,7 @@ get informations of photo file.
 
 returns hashref containing following keys ..
 
-C<'url'>, C<'message'>, C<'comments'>, C<'views'> for scaled.
+C<'url'>, C<'message'>, C<'comments'>, C<'views'> and C<'tags'> for scaled.
 
 just C<'url'> for fullsize.
 
@@ -257,6 +272,7 @@ sub photo_info {
   $sres->{views} =~ s/[^\d]*(\d+).*/$1/;
   trim $sres->{message};
   trim $_->{comment} for @{$sres->{comments}};
+	$sres->{tags} = [] if !exists $sres->{tags};
 
   $sres;
 }
@@ -293,6 +309,41 @@ sub public_timeline
   $sres->{photos};
 }
 
+=head2 tagged I<tag name>
+
+get list of photos that tagged certain name.
+
+returns arrayref of hashref containing following keys,
+C<'id'>, C<'mini'>
+
+=over 1
+
+=item I<tag name>
+
+=back
+
+=cut
+
+sub tagged
+{
+	my ($self, $tagname) = @_;
+
+	croak "invalid tag name @{[$tagname?$tagname:'']}" if !$tagname;
+
+	my $url = URI->new('http://twitpic.com/tag/' . $tagname);
+	my $res = $self->ua->get($url);
+
+	return undef if !$res->is_success;
+
+	my $sres = $self->_tagged_scraper->scrape($res->content);
+
+	my $ret = $sres->{tagged};
+
+	$_->{id} =~ s{^/}{} for @$ret;
+
+	$ret;
+}
+
 =head1 SEEALSO
 
 L<http://twitpic.com/> - Twitpic web site
